@@ -1,5 +1,5 @@
 #
-# $Id: browse.pl,v 0.1.1.1 2001/04/17 11:25:18 ram Exp $
+# $Id: browse.pl,v 1.2 2003/09/29 11:00:50 mshiltonj Exp $
 #
 #  Copyright (c) 2001, Raphael Manfredi
 #  
@@ -8,6 +8,29 @@
 #
 # HISTORY
 # $Log: browse.pl,v $
+# Revision 1.2  2003/09/29 11:00:50  mshiltonj
+#     CGI::Test has changed ownership. The new owner is Steven Hilton
+#     <mshiltonj@mshiltonj.com>.  Many thanks to Raphael Manfredi
+#     and Steve Fink.
+#
+#     CGI::Test is now hosted as a SourceForge project. It is located
+#     at <http://cgi-test.sourceforge.net>.
+#
+#     POD updated to reflect the above.
+#
+#     make() method on various objects has been deprecated, and has been
+#     replaced by more conventional (for me, at least) new() method.
+#     Support for make() may be removed in a later release.
+#
+#     Entire codebase reformatted using perltidy
+#     Go to <http://perltidy.sourceforge.net/> to see how neat it is.
+#
+#     Self-referential object variable name standardized to '$this'
+#     throughout code.
+#
+# Revision 1.1.1.1  2003/09/23 09:47:26  mshiltonj
+# Initial Import
+#
 # Revision 0.1.1.1  2001/04/17 11:25:18  ram
 # patch3: changed test 22 to perform explicit sorting
 #
@@ -20,13 +43,24 @@
 use CGI::Test;
 use Getargs::Long;
 
+use Config;
+
+#
+# This is a fix for nasty Fcntl loading problem: it seems that
+# custom-built Perl fails to allocate some kind of resources, or
+# just tries to load wrong shared object. This results in tests
+# failing miserably; considering that custom builds are very common
+# among CPAN testers, it is a serious problem.
+#
+$ENV{PATH} = $Config{bin} . ':' . $ENV{PATH};
+
 sub browse {
 	my ($method, $enctype) = getargs(@_, [qw(method enctype)]);
 
 	print "1..27\n";
 
 	my $BASE = "http://server:18/cgi-bin";
-	my $ct = CGI::Test->make(
+	my $ct = CGI::Test->new(
 		-base_url	=> $BASE,
 		-cgi_dir	=> "t/cgi",
 	);
